Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/config
diff options
context:
space:
mode:
Diffstat (limited to 'config')
-rw-r--r--config/config.sample.php26
1 files changed, 22 insertions, 4 deletions
diff --git a/config/config.sample.php b/config/config.sample.php
index 231a34f825b..4de3371ea4b 100644
--- a/config/config.sample.php
+++ b/config/config.sample.php
@@ -71,13 +71,14 @@ $CONFIG = array(
'trusted_domains' =>
array (
'demo.example.org',
- 'otherdomain.example.org:8080',
+ 'otherdomain.example.org',
),
/**
* Where user files are stored; this defaults to ``data/`` in the ownCloud
* directory. The SQLite database is also stored here, when you use SQLite.
*/
'datadirectory' => '/var/www/owncloud/data',
@@ -134,6 +135,12 @@ $CONFIG = array(
),
/**
+ * sqlite3 journal mode can be specified using this config parameter - can be 'WAL' or 'DELETE'
+ * see for more details https://www.sqlite.org/wal.html
+ */
+'sqlite.journal_mode' => 'DELETE',
+
+/**
* Indicates whether the ownCloud instance was installed successfully; ``true``
* indicates a successful installation, and ``false`` indicates an unsuccessful
* installation.
@@ -434,6 +441,15 @@ $CONFIG = array(
*/
'check_for_working_htaccess' => true,
+/**
+ * In certain environments it is desired to have a read-only config file.
+ * When this switch is set to ``true`` ownCloud will not verify whether the
+ * configuration is writable. However, it will not be possible to configure
+ * all options via the web-interface. Furthermore, when updating ownCloud
+ * it is required to make the config file writable again for the update
+ * process.
+ */
+'config_is_read_only' => false,
/**
* Logging
@@ -529,6 +545,7 @@ $CONFIG = array(
/**
* When enabled, admins may install apps from the ownCloud app store.
+ * The app store is disabled by default for ownCloud Enterprise Edition
*/
'appstoreenabled' => true,
@@ -619,7 +636,7 @@ $CONFIG = array(
* concerns:
*
* - OC\Preview\Illustrator
- * - OC\Preview\Movies
+ * - OC\Preview\Movie
* - OC\Preview\MSOffice2003
* - OC\Preview\MSOffice2007
* - OC\Preview\MSOfficeDoc
@@ -824,7 +841,8 @@ $CONFIG = array(
),
/**
- * Database types that are supported for installation.
+ * Database types that are supported for installation. (SQLite is available only in
+ * ownCloud Community Edition, oci and mssql only for the Enterprise Edition)
*
* Available:
* - sqlite (SQLite3)
@@ -71,13 +71,14 @@ $CONFIG = array(
/**
* Where user files are stored; this defaults to ``data/`` in the ownCloud
- * directory. The SQLite database is also stored here, when you use SQLite.
+ * directory. The SQLite database is also stored here, when you use SQLite. (SQLite is
+ * available only in ownCloud Community Edition)
*/
'datadirectory' => '/var/www/owncloud/data',